@@ -3,10 +3,18 @@ from __future__ import division, print_function
 import os
 import hashlib
 from unittest import TestCase, main
+import doctest
 
 from tomcrypt.hash import *
 from tomcrypt import hash
 
+from . import get_doctests
+
+
+def load_tests(loader, tests, ignore):
+    tests.addTests(get_doctests(hash))
+    return tests
+
 
 class TestHashed(TestCase):
 
