@@ -1,8 +1,17 @@
 from unittest import TestCase, main
 from base64 import b16encode
+import doctest
 
 from tomcrypt import prng
 
+from . import get_doctests
+
+
+def load_tests(loader, tests, ignore):
+    tests.addTests(get_doctests(prng))
+    return tests
+
+
 class TestPRNG(TestCase):
     
     def test_library(self):
